import * as pulumi from "@pulumi/pulumi";
/**
 * The ``postgresql.PhysicalReplicationSlot`` resource creates and manages a physical replication slot on a PostgreSQL
 * server. This is useful to setup a cross datacenter replication, with Patroni for example, or permit
 * any stand-by cluster to replicate physically data.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const mySlot = new postgresql.PhysicalReplicationSlot("my_slot", {name: "my_slot"});
 * ```
 */
export declare class PhysicalReplicationSlot extends pulumi.CustomResource {
    /**
     * Get an existing PhysicalReplicationSlot resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: PhysicalReplicationSlotState, opts?: pulumi.CustomResourceOptions): PhysicalReplicationSlot;
    /**
     * Returns true if the given object is an instance of PhysicalReplicationSlot.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is PhysicalReplicationSlot;
    /**
     * The name of the replication slot.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Create a PhysicalReplicationSlot resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PhysicalReplicationSlotArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering PhysicalReplicationSlot resources.
 */
export interface PhysicalReplicationSlotState {
    /**
     * The name of the replication slot.
     */
    name?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a PhysicalReplicationSlot resource.
 */
export interface PhysicalReplicationSlotArgs {
    /**
     * The name of the replication slot.
     */
    name?: pulumi.Input<string>;
}
