import * as pulumi from "@pulumi/pulumi";
/**
 * The `postgresql.Subscription` resource creates and manages a publication on a PostgreSQL
 * server.
 *
 * ## Usage
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as postgresql from "@pulumi/postgresql";
 *
 * const subscription = new postgresql.Subscription("subscription", {
 *     name: "subscription",
 *     conninfo: "host=localhost port=5432 dbname=mydb user=postgres password=postgres",
 *     publications: ["publication"],
 * });
 * ```
 *
 * ## Postgres documentation
 *
 * - https://www.postgresql.org/docs/current/sql-createsubscription.html
 */
export declare class Subscription extends pulumi.CustomResource {
    /**
     * Get an existing Subscription resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param state Any extra arguments used during the lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, state?: SubscriptionState, opts?: pulumi.CustomResourceOptions): Subscription;
    /**
     * Returns true if the given object is an instance of Subscription.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Subscription;
    /**
     * The connection string to the publisher. It should follow the [keyword/value format](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING)
     */
    readonly conninfo: pulumi.Output<string>;
    /**
     * Specifies whether the command should create the replication slot on the publisher. Default behavior is true
     */
    readonly createSlot: pulumi.Output<boolean | undefined>;
    /**
     * Which database to create the subscription on. Defaults to provider database.
     */
    readonly database: pulumi.Output<string>;
    /**
     * The name of the publication.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Names of the publications on the publisher to subscribe to
     */
    readonly publications: pulumi.Output<string[]>;
    /**
     * Name of the replication slot to use. The default behavior is to use the name of the subscription for the slot name
     */
    readonly slotName: pulumi.Output<string | undefined>;
    /**
     * Create a Subscription resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubscriptionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * Input properties used for looking up and filtering Subscription resources.
 */
export interface SubscriptionState {
    /**
     * The connection string to the publisher. It should follow the [keyword/value format](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING)
     */
    conninfo?: pulumi.Input<string>;
    /**
     * Specifies whether the command should create the replication slot on the publisher. Default behavior is true
     */
    createSlot?: pulumi.Input<boolean>;
    /**
     * Which database to create the subscription on. Defaults to provider database.
     */
    database?: pulumi.Input<string>;
    /**
     * The name of the publication.
     */
    name?: pulumi.Input<string>;
    /**
     * Names of the publications on the publisher to subscribe to
     */
    publications?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the replication slot to use. The default behavior is to use the name of the subscription for the slot name
     */
    slotName?: pulumi.Input<string>;
}
/**
 * The set of arguments for constructing a Subscription resource.
 */
export interface SubscriptionArgs {
    /**
     * The connection string to the publisher. It should follow the [keyword/value format](https://www.postgresql.org/docs/current/libpq-connect.html#LIBPQ-CONNSTRING)
     */
    conninfo: pulumi.Input<string>;
    /**
     * Specifies whether the command should create the replication slot on the publisher. Default behavior is true
     */
    createSlot?: pulumi.Input<boolean>;
    /**
     * Which database to create the subscription on. Defaults to provider database.
     */
    database?: pulumi.Input<string>;
    /**
     * The name of the publication.
     */
    name?: pulumi.Input<string>;
    /**
     * Names of the publications on the publisher to subscribe to
     */
    publications: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Name of the replication slot to use. The default behavior is to use the name of the subscription for the slot name
     */
    slotName?: pulumi.Input<string>;
}
